ChromatinHD analyzes single-cell ATAC+RNA data using the raw fragments as input, by automatically adapting the scale at which relevant chromatin changes on a per-position, per-cell, and per-gene basis. Currently, the following models are supported:

## Pred

To learn where and how accessibility is predictive for gene expression

## Diff

To understand the differences in accessibilty between cell types/states

## Time

To learn where and how accessibility is predictive over (pseudo)time

## Dime

To learn the differences in accessibility over (pseudo)time